* [Home](https://help.sap.com/docs/)
  * [SAP LeanIX](https://help.sap.com/docs/leanix)
  * …
  * [Custom Reports](https://help.sap.com/docs/leanix/ea/custom-reports)
  * Building Your First Custom Report
